@@ -11,6 +11,8 @@
 #include <aws/common/byte_buf.h>
 #include <aws/common/date_time.h>
 
+AWS_PUSH_SANE_WARNING_LEVEL
+
 struct aws_credentials;
 
 typedef bool(aws_should_sign_header_fn)(const struct aws_byte_cursor *name, void *userdata);
@@ -306,5 +308,6 @@ AWS_AUTH_API
 int aws_validate_aws_signing_config_aws(const struct aws_signing_config_aws *config);
 
 AWS_EXTERN_C_END
+AWS_POP_SANE_WARNING_LEVEL
 
 #endif /* AWS_AUTH_SIGNING_CONFIG_H */
